# New in 0.18.0 (2022-10-12)

## Major Changes

-   Add latent mode support in {class}`~scvi.model.SCVI` [#1672]. This allows for loading a model using latent representations only (i.e. without the full counts). Not only does this speed up inference by using the cached latent distribution parameters (thus skipping the encoding step), but this also helps in scenarios where the full counts are not available but cached latent parameters are. We provide utility functions and methods to dynamically convert a model to latent mode.
-   Added {class}`~scvi.external.SCAR` as an external model for ambient RNA removal [#1683].
-   Add weight support to {class}`~scvi.model.MULTIVI` [#1697].

## Minor changes

-   Faster inference in PyTorch with `torch.inference_mode` [#1695].
-   Upgrade to Lightning 1.6 [#1719].
-   Update CI workflow to separate static code checking from pytest [#1710].
-   Add Python 3.10 to CI workflow [#1711].
-   Add {meth}`~scvi.data.AnnDataManager.register_new_fields` [#1689].
-   Use sphinxcontrib-bibtex for references [#1731].
-   {meth}`~scvi.model.base.VAEMixin.get_latent_representation`: more explicit and better docstring [#1732].
-   Replace custom attrdict with {class}`~ml_collections` implementation [#1696].

## Breaking changes

None

## Bug Fixes

-   Fix links for breast cancer and mouse datasets [#1709].
-   fix quick start notebooks not showing [#1733].

## Contributors

-   [@watiss]
-   [@adamgayoso]
-   [@martinkim0]
-   [@ricomnl]
-   [@marianogabitto]

[#1695]: https://github.com/YosefLab/scvi-tools/pull/1695
[#1696]: https://github.com/YosefLab/scvi-tools/pull/1696
[#1719]: https://github.com/YosefLab/scvi-tools/pull/1719
[#1710]: https://github.com/YosefLab/scvi-tools/pull/1710
[#1672]: https://github.com/YosefLab/scvi-tools/pull/1672
[#1709]: https://github.com/YosefLab/scvi-tools/pull/1709
[#1711]: https://github.com/YosefLab/scvi-tools/pull/1711
[#1683]: https://github.com/YosefLab/scvi-tools/pull/1683
[#1689]: https://github.com/YosefLab/scvi-tools/pull/1689
[#1697]: https://github.com/YosefLab/scvi-tools/pull/1697
[#1731]: https://github.com/YosefLab/scvi-tools/pull/1731
[#1732]: https://github.com/YosefLab/scvi-tools/pull/1732
[#1733]: https://github.com/YosefLab/scvi-tools/pull/1733
[@watiss]: https://github.com/watiss
[@adamgayoso]: https://github.com/adamgayoso
[@martinkim0]: https://github.com/martinkim0
[@ricomnl]: https://github.com/ricomnl
[@marianogabitto]: https://github.com/marianogabitto
